@@ -3,7 +3,7 @@
 
 
 <category>
-Misc
+Virtualization
 </category>
 
 <name>
@@ -73,7 +73,7 @@ VirtualBox
 </description>
 
 <installable>
-all
+64
 </installable>
 
 <screenshot>https://screenshots.debian.net/screenshots/000/015/010/large.png</screenshot>
