@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -72,7 +72,7 @@ AirVPN
 </description>
 
 <installable>
-all
+32,64
 </installable>
 
 <screenshot>none</screenshot>
