@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -72,16 +72,14 @@ Megasync
 </description>
 
 <installable>
-all
+32,64
 </installable>
 
 <screenshot></screenshot>
 
 <preinstall>
-echo "deb https://mega.nz/linux/MEGAsync/Debian_10.0/ ./">/etc/apt/sources.list.d/mxpitemp.list
-wget https://mega.nz/linux/MEGAsync/Debian_10.0/Release.key -O /tmp/megarelease.key
-apt-key add /tmp/megarelease.key
-rm /tmp/megarelease.key
+echo "deb https://mega.nz/linux/repo/Debian_12/ ./">/etc/apt/sources.list.d/mxpitemp.list
+curl -sS https://mega.nz/linux/repo/Debian_12/Release.key | gpg --dearmor --yes -o /etc/apt/trusted.gpg.d/megasync.gpg
 apt-get update
 </preinstall>
 
